# Ledger

## What is Ledger

Ledger is a personal finance management app that enables users to log and track their income and expenses. Users can create entries by specifying the transaction type (income or expense), amount, category (e.g., groceries, salary, entertainment), and date. The app includes a summary screen for a quick overview of finances and a detailed transaction list for reviewing all logged entries. Users can edit or delete entries as needed, ensuring accurate record-keeping. FinanceFlow helps users stay on top of their budget with a clear and organized interface.

## The Team

[Xaver Drabik](https://www.linkedin.com/in/xaverdrabik/) & [Florian Kraushofer](https://www.linkedin.com/in/florian-kraushofer-16892b26a/)

## App Concept

### Use Case
Primary Use Case:
- Tracking and Managing Personal Finances
- Viewing Financial Summaries
- Logging Transactions
- Organizing Finances by Categories
- Financial Planning
- Monitoring Budgets

### Target Users
People who want a simple and effective way to manage their personal finances.
People who want to stay organized by tracking their income and expenses, categorizing transactions, and gaining insights into their financial habits.

Like:
- Freelancers
- Students
- Budget-Conscious Individuals
- Small Business Owners

### Mockups

![Mockup](mockup.png)
![Userflow](UserFlow.png)

## Usability Testing Plan
### Experimental Questions & Variables
1. Question: Did you find the app easy to use?
	- IV: App navigation design (e.g., layout, menu structure, or usability features).
	- DV: User-reported issues or difficulties while navigating.
	- Methods: SEQ Question

2. Question: Does the user find Categories useful?
	- IV: Presence or design of the Categories feature.
	- DV: User perception of usefulness (e.g., measured via survey or rating).
	- Method: Likert scale How useful was it?
3. Question: Does the user find Categories?
	- IV: Visibility or accessibility of the Categories feature.
	- DV: User success in locating or using Categories.
	- Method: Task Completion Testing

4. Question: Does the icon selection affect user satisfaction?
	- IV: Icon design or selection (e.g., different icon styles or clarity).
	- DV: User satisfaction (e.g., measured via survey or rating).
	- Method: Open Question

5. Question: How long does it take for a user to add a Category?
	- IV: Process or interface for adding a Category (e.g., number of steps, clarity of instructions).
	- DV: Time taken to complete the task.
	- Method: Time till completion

6. Question: How long does it take for a user to add a Transaction?
	- IV: Process or interface for adding a Transaction (e.g., simplicity, number of fields).
	- DV: Time taken to complete the task.
	- Method: Time till completion

### Heuristic Evaluation 
Based off of Nielsen’s 10 Heuristics. Done by both team members based on the Mockup. Results were implemented in the android application.
1. Visibility of System Status
	- Issue: Users may not be immediately aware of changes to their balance after adding or editing a transaction, as there is no clear feedback.
	- Recommendations: Implement a visual or auditory feedback system (e.g., a confirmation message or animation or redirect to the Balance overview) to inform users when their balance updates.

2. Match Between System and the Real World
	- Issues: None
	- Recommendations: None

3. User Control and Freedom
	- Issues: Users might want to create their own categories rather than use the predefined ones.
	- Recommendations: Introduce a feature to add and delete your own categories.
4. Consistency and Standards
	- Issues: The "Your Balance" and the name of the transaction do not share the same font
	- Recommendations: Standardize all texts to use the same font, and color scheme for a cohesive user experience.

5. Error Prevention
	- Issues: Users might enter invalid data, such as symbols as the amount, without receiving a warning, leading to potential errors.
	- Recommendations: Add validation checks and warnings to prevent users from entering incorrect data, ensuring errors are caught before submission.

6. Recognition Rather Than Recall
	- Issues: Users may need to remember details about past transactions, such as categories or dates, which could increase cognitive load.
	- Recommendations: Display a detailed transaction history with categories and dates visible at all times, reducing the need for users to recall information.

7. Flexibility and Efficiency of Use
	- Issues: Users may find it time-consuming to navigate through multiple screens or steps to perform common tasks, such as adding or editing transactions.
	- Recommendations: Ensure that all frequently used actions, like adding or deleting transactions, can be completed in as few steps as possible, with clear and accessible buttons for quick access.
8. Aesthetic and Minimalist Design
	- Issues: The interface might include too many visual elements or colors, which could distract users from focusing on their primary tasks, such as managing transactions or checking their balance.
	- Recommendations: Ensure that the design remains clean and focused by using a limited color palette and removing any unnecessary decorative elements, keeping the interface visually simple and task-oriented.

9. Help Users Recognize, Diagnose, and Recover from Errors
	- Issues: Error messages may not clearly explain what went wrong or how to fix it, leaving users confused.
	- Recommendations: Provide detailed error messages in plain language, including actionable steps to resolve the issue.

10. Help and Documentation
	- Issues: Help and Documentation may be important and nice to have but out of scope for this version of the design. 
	- Recommendations: For now, focus on maintaining the clarity and simplicity of the current help documentation. If these advanced features are considered in future updates, ensure that corresponding help resources are developed to support them.

## Results

### Participant Demographics
- **Number of Test Subjects:** 5
- **Demographics:** Not specified in the data.

---

### Quantitative Evaluation

#### Task Completion Time

##### Adding a Category:
| Participant | Time (seconds) |
|-------------|----------------|
| 1           | 18             |
| 2           | 69             |
| 3           | 40             |
| 4           | 18             |
| 5           | 15             |

**Average Time:** 32 seconds

##### Adding a Transaction:

| Participant | Time (seconds) |
|-------------|----------------|
| 1           | 18             |
| 2           | 11             |
| 3           | 60             |
| 4           | 43             |
| 5           | 30             |

**Average Time:** 32.4 seconds

![Time to add Category vs. Time to add Transaction](ReportImages/timeToAddCategory_vs_timeToAddTransaction.jpg)

**Time to Add Category vs. Time to Add Transaction:**
- The box plot shows variability in task completion times, with some participants taking significantly longer than others.
  - For **adding a category**, Participant 2 took 69 seconds, which is an outlier compared to the others (15–40 seconds).
  - For **adding a transaction**, Participant 3 took 60 seconds, while others completed the task in 11–43 seconds.
- This variability suggests that some users may have struggled with the interface or navigation, particularly for adding categories.

---

#### User Satisfaction Scores

##### Ease of Use (Scale: 1-7):

| Participant | Score |
|-------------|-------|
| 1           | 7     |
| 2           | 5     |
| 3           | 7     |
| 4           | 7     |
| 5           | 6     |

**Average Score:** 6.4

![Ease of use Graph](ReportImages/easeOfUse.jpg)

**Insights from Bar Chart (Ease of Use Responses):**
- The bar chart shows that most participants rated the app highly for ease of use, with four out of five giving scores of 6 or 7.
- Participant 2 gave a lower score of 5, which aligns with their feedback about difficulty finding categories and longer task completion times.
- The chart reinforces the overall positive perception of the app's usability but highlights the need to address specific pain points for users like Participant 2.

---

##### Usefulness of Categories (Scale: 1-5):

| Participant | Score |
|-------------|-------|
| 1           | 3     |
| 2           | 4     |
| 3           | 4     |
| 4           | 5     |
| 5           | 5     |

**Average Score:** 4.2

![Usefulness of categories vs. Found categories](ReportImages/usefulnessOfCategories_vs_foundCategories.jpg)

**Usefulness of Categories vs. Found Categories:**
- The stacked bar chart shows a strong correlation between finding categories and perceiving them as useful.
  - Four out of five participants found the categories and rated their usefulness highly (scores of 4 or 5).
  - Participant 2, who did not find the categories initially, still rated their usefulness as 4, suggesting that they recognized the potential value once they located them.
- The chart highlights the importance of making categories easy to find, as discoverability directly impacts perceived usefulness.

---

#### Task Success Rate

![Success rate of finding categories.jpg](ReportImages/successRateOfFindingCategories.jpg)

**Finding Categories:**
  - 4 out of 5 participants (80%) found the categories.
  - 1 participant did not find the categories.

**Percentage of Participants Who Found Categories and Were Satisfied with Icon Selection:**
- The bar chart visually confirms that the majority of participants (80%) successfully found the categories.
- However, the 20% who struggled represent areas for improvement.

---

### Qualitative Feedback

**Positive Feedback:**
- "The app is easy to use." (Participant 1, 3, 4)
- "Categories are useful for organizing transactions." (Participant 4, 5)

**Negative Feedback:**
- "I could not find the categories initially." (Participant 2)
- "The icon selection is missing a Pets category." (Participant 4)

**Suggestions for Improvement:**
- "Add more icons, especially for Pets." (Participant 4)
- "Improve the visibility of categories in the app." (Participant 2)

---

### Updates Made to the App

Based on the feedback and insights from the charts, the following updates were made:

1. **Improved Visibility of System Status:**
   - Added headings for _Category_ and _Transaction_ screens to make navigation more intuitive.

2. **Improved Category Visibility:**
   - Redesigned the categories section to make it more prominent and easier to find, addressing the issue raised by Participant 2.

3. **Expanded Icon Selection:**
   - Added new icons, including a "Pets" category, to address the feedback from Participant 4.

---

### Summary of Insights from Charts

- **Box Plot:** Highlights variability in task completion times, indicating that some users may need additional guidance or a more intuitive interface.
- **Bar Chart (Ease of Use):** Confirms high satisfaction with usability but identifies specific users who faced challenges.
- **Stacked Bar Chart (Usefulness vs. Found Categories):** Shows a clear link between discoverability and perceived usefulness, emphasizing the need for clear category visibility.
- **Pie Chart:** Reinforces that most users were successful but underscores the importance of addressing the minority who struggled.

By integrating these visual insights, the findings become more actionable, guiding targeted improvements to enhance the app's usability and user satisfaction.